import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 7
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.api.akshare.stock_bid_ask_api as stock_bid_ask_api


# 获取最新价格
def get_new_buy_price(symbol):
    stock_bid_ask_df = stock_bid_ask_api.stock_bid_ask_em(symbol)
    sell_5 = list(stock_bid_ask_df['sell_5'])[0]
    if sell_5 != 0:
        return sell_5
    sell_4 = list(stock_bid_ask_df['sell_4'])[0]
    if sell_4 != 0:
        return sell_4

    sell_3 = list(stock_bid_ask_df['sell_4'])[0]
    if sell_3 != 0:
        return sell_4

    sell_2 = list(stock_bid_ask_df['sell_2'])[0]
    if sell_2 != 0:
        return sell_2

    sell_1 = list(stock_bid_ask_df['sell_1'])[0]
    if sell_1 != 0:
        return sell_1
    # 打板价格
    buy_1 = list(stock_bid_ask_df['buy_1'])[0]
    if buy_1 != 0:
        return buy_1


if __name__ == '__main__':
    price = get_new_buy_price('002903')
    print(price)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)
# 大单同步表
BIG_DEAL_NAME = "ths_big_deal_fund"
# 大单选择表
BIG_DEAL_CHOOSE_NAME = "big_deal_fund_choose"
# 实时行情表
REAL_TIME_QUOTES_NOW = 'realtime_quotes_now'
# 当前实时涨停表
TODAY_ZT_POOL = 'today_zt_pool'
# 集合竞价表
CALL_AUCTION_DB_NAME = 'call_auction_signal'
# 实时竞价表
CALL_AUCTION_DB_NAME_REAL_TIME = 'call_auction_signal_realtime'
# 涨停打板表
NOW_TIME_ZT_DA_BAN = 'now_time_zt_da_ban'
# 开盘啦精选指数表
KPL_BEST_CHOOSE_INDEX = 'kpl_best_choose_index'
# 开盘啦详细组成
KPL_BEST_CHOOSE_INDEX_DETAIL = "kpl_best_choose_index_detail"

# 同花顺概念表
THS_CONCEPT_LIST = "ths_concept_list"

# 同花顺概念详情表
THS_STOCK_CONCEPT_DETAIL = "ths_stock_concept_detail"

# 买入股票
BUY_STOCK_NAME = 'trade_stocks'
# 今日排除股票
TODAY_EXCLUDE_STOCK = 'today_exclude_stocks'

# 公司信息
COMPANY_INFO = "company_info"
